@@ -11,97 +11,117 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw(to_ascii to_latin1);
 our %EXPORT_TAGS = ( 'all' => [ @EXPORT ]);
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
-my %ascii = (qw(
-         A
-		 A
-		 A
-		 A
-		 Ae
-		 A
-		 Ae
-		 C
-		 E
-		 E
-		 E
-		 E
-		 I
-		 I
-		 I
-		 I
-		 D
-		 N
-		 O
-		 O
-		 O
-		 O
-		 Oe
-		 x
-		 Oe
-		 U
-		 U
-		 U
-		 Ue
-		 Y
-		 Th
-		 ss 	
-		 a
-		 a
-		 a
-		 a
-		 ae
-		 a
-		 ae
-		 c
-		 e
-		 e
-		 e
-		 e
-		 i
-		 i
-		 i
-		 i
-		 p
-		 n
-		 o
-		 o
-		 o
-		 o
-		 oe
-		 o
-		 oe 
-		 u
-		 u
-		 u
-		 ue
-		 y
-		 th
-		 y
+our %ANSI_TO_ASCII_TRANSLITERATION = (qw(
+         !
+         ct
+         Lb
+         EUR
+         Yen
+         S
+         
+         s
+         a
+         <<
+         --|
+         -
+         -
+         
 		 +-
 		 ^2
 		 ^3
-		 ue
-		 P
-		 .
-		 ^1
          >>
-         <<
+		 1/4
+         1/2
+         3/4
+         ?
+         .
+		 ^1
+         
+		 a
+		 A
+		 a
+         A
+		 a
+		 A
+		 a
+		 A
+		 a
+		 A
+		 ae
+		 Ae
+		 ae
+		 Ae
+		 c
+		 C
+		 D
+		 p
+		 e
+		 E
+		 e
+		 E
+		 e
+		 E
+		 e
+		 E
+		 i
+		 I
+		 i
+		 I
+		 i
+		 I
+		 i
+		 I
+		 n
+		 N
+		 o
+		 o
+		 O
+		 o
+		 O
+		 o
+		 O
+		 o
+		 O
+		 oe
+		 Oe
+		 oe 
+		 Oe
+		 P
+		 ss 	
+		 ue
+		 u
+		 U
+		 u
+		 U
+		 u
+		 U
+		 ue
+		 Ue
+		 x
+		 y
+		 Y
+		 y
+		 th
+		 Th
         ),
 	     ("" => "'",
 	      "" => ",",
           "" => "(R)",
-          "" => "(C)")
+          "" => "(C)",
+          chr(160) => ' ')
     );
 
 # remove all unknown chars
-$ascii{$_} = '' foreach (grep {!defined($ascii{$_})} map {chr} (128..255));
+$ANSI_TO_ASCII_TRANSLITERATION{$_} = '' 
+    for (grep {!defined($ANSI_TO_ASCII_TRANSLITERATION{chr $_})} (128..255));
 
 my $non_ascii_char = join("", map {chr} (128..255));
 
 sub to_ascii($) {
     my $text = shift or return;
-    $text =~ s/([$non_ascii_char])/$ascii{$1}/eg;
+    $text =~ s/([$non_ascii_char])/$ANSI_TO_ASCII_TRANSLITERATION{$1}/eg;
     return $text;
 }
 
@@ -869,6 +889,36 @@ say.
 Please note that both methods take only one scalar as argument and 
 not whole a list.
 
+=head2 to_ascii($string)
+
+The C<to_ascii> method is just simple. It replaces each printable ANSI character
+(codes 160..255) with a (hopefully) sensfull ASCII representation (might be more
+than one character). The ANSI character with codes 128..160 are not printable
+and they are removed by default.
+The transliteration is defined with the global
+C<%Lingua::DE::ASCII::ANSI_TO_ASCII_TRANSLITERATION>
+variable.
+You can change this variable if you want to change the transliteration
+behaviour.
+
+=head2 to_latin1($string)
+
+The C<to_latin1> method is very complex (more than 700 lines of code). It
+retranslates 7-bit ASCII representations into a reasonable german ANSI
+representation. Thus it changes mainly 'ae' to '', 'oe' to '', 'ue' to '',
+'ss' to ''. It also changes some other characters, e.g. '(C)' to '' or in
+words like 'Crepe' it also restores the really writing 'Crpe'.
+
+Of course, the method only tries to change where it should. That
+explains the enormous complexity of this method, as it tries to solve a hard
+linguistic problem with a bit logic and many regular expressions (please also
+look to L<BUGS> if you are interested in known problems).
+
+At the moment you can't change the behaviour of the C<to_latin1> method (e.g.
+switching from the new german spelling to the old one), and I'm not sure whether
+I will enable it. Please inform me, if you feel that it would be important or
+much convenient in a case.
+
 =head2 EXPORT
 
 to_ascii($string)
@@ -886,7 +936,7 @@ Also, it's  hard to find the right spelling for the prefixes "miss-" or "mi-".
 In doubt I tried to use to more common word and in even still a doubt the
 program tries to be conservative, that means it prefers not to translate to an
 umlaut. Reason is that the text is still readable with one "ae","oe","ue" or
-"ss" to much, but a wrong "", "", "" or "" can make it very unreadable.
+"ss" too much, but a wrong "", "", "" or "" can make it very unreadable.
 
 I tried it with a huge list of german words, but please tell me if you find a bug.
 
@@ -895,8 +945,9 @@ This module is intended for ANSI code that is e.g. different from windows coding
 Misspelled words will create a lot of extra mistakes by the program.
 In doubt it's better to write with new Rechtschreibung.
 
-The C<to_latin1> method is not very quick,
-it's programmed to handle as many exceptions as possible.
+The C<to_latin1> method is not very quick (but quick enough to work
+interactively with text files of about 20 KB).
+It's programmed to handle as many exceptions as possible.
 
 I avoided localizations for character handling
 (thus it should work on every computer),
@@ -904,9 +955,23 @@ but the price is that in some rare cases of words with multiple umlauts
 (like "Hkeltlle") some buggy conversions can occur.
 Please tell me if you find such words.
 
+=head1 TESTS
+
+The test scripts (called by e.g. C<make test>) need a long time.
+The reason is that I test it with a huge german word list. Normally you can skip
+this test if there is no failing in the first few seconds.
+
+There are two major reasons why I added so many words to test even to the CPAN
+release. On the one hand, I wanted to give you a chance to detect strange
+behaviour under uncommon circumstances. (I haven't test it under a non-german
+locale based operation system e.g.) On the other hand, I also wanted you to give
+a chance to detect yourself whether a C<to_latin1> result is a bug or a feature.
+(Just search through the content of the test files to determine whether a
+strange looking word is tested for and thus wanted).
+
 =head1 AUTHOR
 
-Janek Schleicher, <bigj@kamelfreund.de>
+Janek Schleicher, E<lt>bigj@kamelfreund.deE<gt>
 
 =head1 SEE ALSO
 
